@@ -86,6 +86,12 @@ func TestDlvTransformer_IsApplicable(t *testing.T) {
 			source:      ImageConfiguration{Env: map[string]string{"GOTRACEBACK": "off"}},
 			result:      true,
 		},
+		{
+			// detect images built by ko: https://github.com/google/ko#static-assets
+			description: "KO_DATA_PATH",
+			source:      ImageConfiguration{Env: map[string]string{"KO_DATA_PATH": "cmd/app/kodata/"}},
+			result:      true,
+		},
 		{
 			description: "entrypoint with dlv",
 			source:      ImageConfiguration{Entrypoint: []string{"dlv", "exec", "--headless"}},
@@ -97,6 +103,11 @@ func TestDlvTransformer_IsApplicable(t *testing.T) {
 			launcher:    "launcher",
 			result:      true,
 		},
+		{
+			description: "ko author",
+			source:      ImageConfiguration{Author: "github.com/google/ko"},
+			result:      true,
+		},
 		{
 			description: "entrypoint /bin/sh",
 			source:      ImageConfiguration{Entrypoint: []string{"/bin/sh"}},
