@@ -40,7 +40,7 @@ type Runner interface {
 	Apply(context.Context, io.Writer) error
 	ApplyDefaultRepo(tag string) (string, error)
 	Build(context.Context, io.Writer, []*latestV1.Artifact) ([]graph.Artifact, error)
-	Cleanup(context.Context, io.Writer) error
+	Cleanup(context.Context, io.Writer, bool) error
 	Dev(context.Context, io.Writer, []*latestV1.Artifact) error
 	Deploy(context.Context, io.Writer, []graph.Artifact) error
 	DeployAndLog(context.Context, io.Writer, []graph.Artifact) error
